==> 4.7.4.tar.gz: terraform-provider-decort/wiki/4.7.2/06.02.115-Data_decort_cb_audits_export_to_file.md <==
Функция доступна в провайдере версии 4.7.0 и выше.

_Data source_ функция **decort_cb_audits_export_to_file** служит для получения архива с информации об указанном событиях системы, вызванном действиями пользователей.

## Аргументы
_Data source_ функция **decort_cb_audits_export_to_file** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| file_path | string | :х: | путь, где будет создан архив, если не указан, создается в директории с main.tf с именем "audits.tar.gz" |

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_cb_audits_export_to_file** возвращает в указанную при вызове переменную следующие параметры:

| Параметр | Тип | Описание |
| --- | --- | --- |
| file_path | string | указанный путь |
| id | string | UUID запроса |

## Пример использования
Пример вызова _data source_ функции **decort_cb_audits_export_to_file**:

```terraform
data "decort_cb_audits_export_to_file" "audit" {
  #путь, где будет создан архив, если не указан, создается в директории с main.tf с именем "audits.tar.gz"
  #обязательный параметр
  #тип - строка
  file_path = "abcdefg.tar.gz"
}
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.7.2/04.02-Инициализация-Terraform-провайдера-DECORT.md) и [пример](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.7.2/02.-Пример-работы.md)). 

После успешного завершения такого вызова **decort_cb_audits_export_to_file** в переменной `data.decort_cb_audits_export_to_file.audit` будут сохранены возвращаемые значения.

==> 4.9.0.tar.gz: terraform-provider-decort/wiki/4.9.0/06.02.115-Data_decort_cb_audits_export_to_file.md <==
Функция доступна в провайдере версии 4.7.0 и выше.

_Data source_ функция **decort_cb_audits_export_to_file** служит для получения архива с информации об указанном событиях системы, вызванном действиями пользователей.

## Аргументы
_Data source_ функция **decort_cb_audits_export_to_file** принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| file_path | string | :х: | путь, где будет создан архив, если не указан, создается в директории с main.tf с именем "audits.tar.gz" |

## Возвращаемые значения
В случае успешного выполнения _data source_ функция **decort_cb_audits_export_to_file** возвращает в указанную при вызове переменную следующие параметры:

| Параметр | Тип | Описание |
| --- | --- | --- |
| file_path | string | указанный путь |
| id | string | UUID запроса |

## Пример использования
Пример вызова _data source_ функции **decort_cb_audits_export_to_file**:

```terraform
data "decort_cb_audits_export_to_file" "audit" {
  #путь, где будет создан архив
  #если не указан, создается в директории с main.tf с именем "audits.tar.gz"
  #обязательный параметр
  #тип - строка
  file_path = "abcdefg.tar.gz"

}
```

Данный пример подразумевает, что ранее по тексту tf-файла выполнена корректная инициализация провайдера (подробнее об инициализации Terraform провайдера DECORT см. соответствующий [раздел](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.9.0/04.02-Инициализация-Terraform-провайдера-DECORT.md) и [пример](https://repository.basistech.ru/BASIS/terraform-provider-decort/src/branch/main/wiki/4.9.0/02.-Пример-работы.md)). 

После успешного завершения такого вызова **decort_cb_audits_export_to_file** в переменной `data.decort_cb_audits_export_to_file.audit` будут сохранены возвращаемые значения.
